==> ejc-sddjsorg-impl-3.0.0-20211020.020248-35-sources.jar: com/ejianc/business/production/bean/CurrencyEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-货币出资情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_currency")
public class CurrencyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private java.lang.Long pid; // 主表id(申请单id)
    @TableField(value="in_out_captail")
    private java.lang.String inOutCaptail; // 内/外部出资方
    @TableField(value="captail_name")
    private java.lang.String captailName; // 出资方名称
    @TableField(value="unified_social_credit_code")
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用编码
    @TableField(value="captail_type")
    private java.lang.String captailType; // 出资人类别
    @TableField(value="subscribed_capital")
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    @TableField(value="subscribed_capital_big")
    private java.lang.String subscribedCapitalBig; // 认缴资本(大写)
    @TableField(value="paid_capital")
    private java.math.BigDecimal paidCapital; // 实缴资本
    @TableField(value="paid_capital_big")
    private java.lang.String paidCapitalBig; // 实缴资本(大写)
    @TableField(value="equity_ratio")
    private java.math.BigDecimal equityRatio; // 股权比例
    
    
    

    /**
     * 主表id(申请单id)
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public java.lang.String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(java.lang.String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public java.lang.String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(java.lang.String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public java.lang.String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(java.lang.String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }
    
}

==> ejc-sddjsorg-impl-3.0.0-20211021.092501-45-sources.jar: com/ejianc/business/production/bean/CurrencyEntity.java <==
package com.ejianc.business.production.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-货币出资情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_currency")
public class CurrencyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private java.lang.Long pid; // 主表id(申请单id)
    @TableField(value="in_out_captail")
    private java.lang.String inOutCaptail; // 内/外部出资方
    @TableField(value="captail_name")
    private java.lang.String captailName; // 出资方名称
    @TableField(value="unified_social_credit_code")
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用编码
    @TableField(value="captail_type")
    private java.lang.String captailType; // 出资人类别
    @TableField(value="subscribed_capital")
    private java.math.BigDecimal subscribedCapital; // 认缴资本
    @TableField(value="subscribed_capital_big")
    private java.lang.String subscribedCapitalBig; // 认缴资本(大写)
    @TableField(value="paid_capital")
    private java.math.BigDecimal paidCapital; // 实缴资本
    @TableField(value="paid_capital_big")
    private java.lang.String paidCapitalBig; // 实缴资本(大写)
    @TableField(value="equity_ratio")
    private java.math.BigDecimal equityRatio; // 股权比例
    @TableField(value="whether_shareholder")
    private Boolean whetherShareholder;//是否新股东

    @TableField(value="capital_increase_front_ratio")
    private BigDecimal capitalIncreaseFrontRatio;


    /**
     * 主表id(申请单id)
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 主表id(申请单id)
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }
    /**
     * 内/外部出资方
     */
    public java.lang.String getInOutCaptail() {
        return inOutCaptail;
    }

    /**
     * 内/外部出资方
     */
    public void setInOutCaptail(java.lang.String inOutCaptail) {
        this.inOutCaptail = inOutCaptail;
    }
    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用编码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用编码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 出资人类别
     */
    public java.lang.String getCaptailType() {
        return captailType;
    }

    /**
     * 出资人类别
     */
    public void setCaptailType(java.lang.String captailType) {
        this.captailType = captailType;
    }
    /**
     * 认缴资本
     */
    public java.math.BigDecimal getSubscribedCapital() {
        return subscribedCapital;
    }

    /**
     * 认缴资本
     */
    public void setSubscribedCapital(java.math.BigDecimal subscribedCapital) {
        this.subscribedCapital = subscribedCapital;
    }
    /**
     * 认缴资本(大写)
     */
    public java.lang.String getSubscribedCapitalBig() {
        return subscribedCapitalBig;
    }

    /**
     * 认缴资本(大写)
     */
    public void setSubscribedCapitalBig(java.lang.String subscribedCapitalBig) {
        this.subscribedCapitalBig = subscribedCapitalBig;
    }
    /**
     * 实缴资本
     */
    public java.math.BigDecimal getPaidCapital() {
        return paidCapital;
    }

    /**
     * 实缴资本
     */
    public void setPaidCapital(java.math.BigDecimal paidCapital) {
        this.paidCapital = paidCapital;
    }
    /**
     * 实缴资本(大写)
     */
    public java.lang.String getPaidCapitalBig() {
        return paidCapitalBig;
    }

    /**
     * 实缴资本(大写)
     */
    public void setPaidCapitalBig(java.lang.String paidCapitalBig) {
        this.paidCapitalBig = paidCapitalBig;
    }
    /**
     * 股权比例
     */
    public java.math.BigDecimal getEquityRatio() {
        return equityRatio;
    }

    /**
     * 股权比例
     */
    public void setEquityRatio(java.math.BigDecimal equityRatio) {
        this.equityRatio = equityRatio;
    }

    public Boolean getWhetherShareholder() {
        return whetherShareholder;
    }

    public void setWhetherShareholder(Boolean whetherShareholder) {
        this.whetherShareholder = whetherShareholder;
    }

    public BigDecimal getCapitalIncreaseFrontRatio() {
        return capitalIncreaseFrontRatio;
    }

    public void setCapitalIncreaseFrontRatio(BigDecimal capitalIncreaseFrontRatio) {
        this.capitalIncreaseFrontRatio = capitalIncreaseFrontRatio;
    }
}
